pub async fn record_audit_log(
fallback_db: &DatabaseConnection,
request: AuditLogCreate,
)Expand description
Records through the global manager, or writes directly through fallback_db before startup.
pub async fn record_audit_log(
fallback_db: &DatabaseConnection,
request: AuditLogCreate,
)Records through the global manager, or writes directly through fallback_db before startup.